import * as ts from 'typescript';
export declare const keywords: ts.SyntaxKind[];
export declare function resolveType(typeNode?: ts.TypeNode): Type;
/**
 * Used to identify union types of a primitive and array of the same primitive, e.g. `string | string[]`
 */
export declare function getCommonPrimitiveAndArrayUnionType(typeNode?: ts.TypeNode): Type | null;
export declare function getLiteralValue(expression: ts.Expression): any;
export declare function getFirstMatchingJSDocTagName(node: ts.Node, isMatching: (t: ts.JSDocTag) => boolean): string | undefined;
export declare function getDecoratorName(node: ts.Node, isMatching: (identifier: DecoratorData) => boolean): string | undefined;
export interface DecoratorData {
    text: string;
    arguments: Array<any>;
    typeArguments: Array<any>;
}
export declare function getDecorators(node: ts.Node, isMatching: (identifier: DecoratorData) => boolean): Array<DecoratorData>;
export interface ArrayType extends Type {
    elementType: Type;
}
export interface EnumerateType extends Type {
    enumMembers: Array<string>;
}
export interface ObjectType extends Type {
    properties: Array<Property>;
}
export interface ReferenceType extends Type {
    description: string;
    properties: Array<Property>;
    additionalProperties?: Array<Property>;
}
export interface Property {
    description: string;
    name: string;
    type: Type;
    required: boolean;
}
export interface Type {
    typeName: string;
    typeArgument?: Type;
}
export declare function getProperties(properties: Array<Property>): {
    [propertyName: string]: Schema;
};
interface Schema extends BaseSchema {
    $ref?: string;
    allOf?: [Schema];
    additionalProperties?: boolean | {
        [ref: string]: string;
    };
    properties?: {
        [propertyName: string]: Schema;
    };
    discriminator?: string;
    readOnly?: boolean;
    example?: {
        [exampleName: string]: Example;
    };
    required?: Array<string>;
}
interface BaseSchema {
    format?: string;
    title?: string;
    description?: string;
    default?: string | boolean | number | Object;
    multipleOf?: number;
    maximum?: number;
    exclusiveMaximum?: number;
    minimum?: number;
    exclusiveMinimum?: number;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
    maxItems?: number;
    minItems?: number;
    uniqueItems?: boolean;
    maxProperties?: number;
    minProperties?: number;
    enum?: [string];
    type?: string;
    items?: Schema | [Schema];
}
interface Example {
}
export {};
